# pylint: disable=missing-docstring

from click.testing import CliRunner

from nengo_bones.scripts import check_bones, generate_bones
from nengo_bones.tests.utils import write_file, assert_exit


def test_files(tmpdir):
    write_file(tmpdir, ".nengobones.yml", """
        project_name: Dumdum
        pkg_name: dummy
        repo_name: dummy_org/dummy
        contributors_rst: {}
    """)
    check_args = [
        "--root-dir", str(tmpdir),
        "--conf-file", str(tmpdir.join(".nengobones.yml")),
        "--verbose",
    ]

    # file not found
    result = CliRunner().invoke(check_bones.main, check_args)

    assert_exit(result, 0)
    assert ".travis.yml:\n  File not found" in result.output

    # generate a valid contributors.rst
    result = CliRunner().invoke(
        generate_bones.main,
        ["--conf-file", str(tmpdir.join(".nengobones.yml")),
         "--output-dir", str(tmpdir),
         "contributors-rst"])
    assert_exit(result, 0)

    # successful check
    result = CliRunner().invoke(check_bones.main, check_args)

    assert_exit(result, 0)
    assert "CONTRIBUTORS.rst:\n  Up to date" in result.output

    # change content of file
    with open(str(tmpdir.join("CONTRIBUTORS.rst")), "a") as f:
        f.write("x")
    result = CliRunner().invoke(check_bones.main, check_args)
    assert_exit(result, 1)
    assert "CONTRIBUTORS.rst:\n  Content does not match" in result.output
    assert "  Full diff" in result.output

    # not generated by nengo-bones
    with open(str(tmpdir.join("CONTRIBUTORS.rst")), "w") as f:
        f.write("a contributor")
    result = CliRunner().invoke(check_bones.main, check_args)
    assert_exit(result, 0)
    assert "CONTRIBUTORS.rst:\n  This file was not generated with nengo-bones"
